"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeepKeySDK = void 0;
const axios_1 = __importDefault(require("axios"));
const axiosConfig = (key) => { return { headers: { Authorization: key } }; };
const KeepKeySDK = (config) => ({
    service: {
        pair: () => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/pair`, {
                serviceName: config.serviceName,
                serviceImageUrl: config.serviceImageUrl
            }, axiosConfig(config.serviceKey)).then(() => {
                resolve({ success: true });
            }).catch((err) => {
                resolve({ success: false, error: 'App rejected pairing', code: err.response.status });
            });
        }),
        verifyAuth: () => new Promise((resolve, reject) => {
            axios_1.default.get(`${config.baseApiURL}/auth/verify`, axiosConfig(config.serviceKey)).then(() => {
                resolve({ success: true });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
    },
    pubkeys: {
        getPublicKeys: (pubkeys) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/getPublicKeys`, { ...pubkeys }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, pubkey: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
        btcGetAddress: (body) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/btcGetAddress`, { ...body }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, pubkey: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
        rippleGetAddress: (body) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/rippleGetAddress`, { ...body }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, pubkey: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
        ethGetAddress: (body) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/ethGetAddress`, { ...body }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, pubkey: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
        thorchainGetAddress: (body) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/thorchainGetAddress`, { ...body }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, pubkey: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
        osmosisGetAddress: (body) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/osmosisGetAddress`, { ...body }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, pubkey: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
        binanceGetAddress: (body) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/binanceGetAddress`, { ...body }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, pubkey: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
        cosmosGetAddress: (body) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/cosmosGetAddress`, { ...body }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, pubkey: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
    },
    sign: {
        signTx: (body) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/sign`, { ...body }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, tx: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
        btcSignTx: (body) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/btcSignTx`, { ...body }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, tx: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
        thorchainSignTx: (body) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/thorchainSignTx`, { ...body }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, tx: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
        cosmosSignTx: (body) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/cosmosSignTx`, { ...body }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, tx: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
        osmosisSignTx: (body) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/osmosisSignTx`, { ...body }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, tx: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
        rippleSignTx: (body) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/rippleSignTx`, { ...body }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, tx: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
        binanceSignTx: (body) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/binanceSignTx`, { ...body }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, tx: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
        ethSignTx: (body) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/ethSignTx`, { ...body }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, tx: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        }),
        eosSignTx: (body) => new Promise((resolve, reject) => {
            axios_1.default.post(`${config.baseApiURL}/eosSignTx`, { ...body }, axiosConfig(config.serviceKey)).then((resp) => {
                resolve({ success: true, tx: resp.data });
            }).catch((err) => {
                resolve({ success: false, error: err.response.data, code: err.response.status });
            });
        })
    }
});
exports.KeepKeySDK = KeepKeySDK;
